#!/bin/bash

if [ x$usearch == x ] ; then
	echo Must set \$usearch >> /dev/stderr
	exit 1
fi

version=`$usearch -version | sed "-es/usearch v9.*/v9/"`

if [ x$version != xv9 ] ; then
	echo "usearch version too old, need v9" >> /dev/stderr
	exit 1
fi

out=../out/mock

rm -rf $out
mkdir -p $out

$usearch -fastq_mergepairs ../fq/Mock*_R1_*.fastq -fastqout $out/merged.fq -log $out/merge.log -fastq_maxdiffs 10 -fastq_maxdiffpct 10

$usearch -fastq_filter $out/merged.fq -fastq_maxee 1.0 -fastqout $out/filtered.fq -relabel Filt -log $out/filter.log

$usearch -fastx_uniques $out/filtered.fq -sizeout -fastaout $out/uniques.fa -relabel Uniq -log $out/uniques.log

$usearch -cluster_otus $out/uniques.fa -minsize 2 -otus $out/otus.fa -relabel Otu -uparseout $out/uniques.up -log $out/cluster_otus.log

$usearch -unoise $out/uniques.fa -fastaout $out/denoised.fa -relabel Den -log $out/unoise.log -minampsize 4

$usearch -uparse_ref $out/otus.fa -db ../ref/HMP_MOCK.v35.fasta -threads 1 -strand both -uparseout $out/otus.uparseref -log $out/otus_uparse_ref.log

$usearch -uparse_ref $out/denoised.fa -db ../ref/HMP_MOCK.v35.fasta -threads 1 -strand both -uparseout $out/denoised.uparseref -log $out/denoised_uparse_ref.log

$usearch -sintax $out/otus.fa -db ../sintax/sintax_16s.fa -strand plus -tabbedout $out/otus_sintax.txt -log $out/sintax.log
