#!/bin/bash

if [ x$usearch == x ] ; then
	echo Must set \$usearch >> /dev/stderr
	exit 1
fi

version=`$usearch -version | sed "-es/usearch v9.*/v9/"`

if [ x$version != xv9 ] ; then
	echo "usearch version too old, need v9" >> /dev/stderr
	exit 1
fi

out=../out/mouse

rm -rf $out
mkdir -p $out

$usearch -fastq_mergepairs ../fq/F3D*_R1_*.fastq -fastqout $out/merged.fq -relabel @ -log $out/merge.log -fastq_maxdiffs 10 -fastq_maxdiffpct 10

$usearch -fastq_filter $out/merged.fq -fastq_maxee 1.0 -fastaout $out/filtered.fa -relabel Filt -log $out/filter.log

$usearch -fastx_uniques $out/filtered.fa -sizeout -relabel Uniq -fastaout $out/uniques.fa -log $out/uniques.log

$usearch -cluster_otus $out/uniques.fa -minsize 2 -otus $out/otus.fa -relabel Otu -log $out/cluster_otus.log

$usearch -unoise $out/uniques.fa -fastaout $out/denoised.fa -relabel Den -log $out/unoise.log -minampsize 4

$usearch -sintax $out/otus.fa -db ../sintax/sintax_16s.fa -strand plus \
  -tabbedout $out/otus_sintax.txt -log $out/sintax.log

$usearch -usearch_global $out/otus.fa -db ../sintax/sintax_16s.fa -strand plus \
  -id 0.97 -alnout $out/otus_ref.aln -userout $out/otus_ref.user -userfields query+target+id

$usearch -usearch_global $out/merged.fq -db $out/otus.fa -strand plus -id 0.97 -log $out/make_otutab.log \
  -otutabout $out/otutab.txt -biomout $out/otutab.json -mothur_shared_out $out/otutab.mothur 

$usearch -usearch_global $out/merged.fq -db $out/denoised.fa -strand plus -id 0.97 -log $out/make_otutab_den.log \
  -otutabout $out/otutab_den.txt -biomout $out/otutab_den.json -mothur_shared_out $out/otutab_den.mothur 
